@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -23,7 +23,7 @@ class KPIMTEXTEDIT_EXPORT RichTextComposerActions : public QObject
 {
     Q_OBJECT
 public:
-    explicit RichTextComposerActions(KPIMTextEdit::RichTextComposerControler *controler, QObject *parent = nullptr);
+    explicit RichTextComposerActions(KPIMTextEdit::RichTextComposerControler *controller, QObject *parent = nullptr);
     ~RichTextComposerActions() override;
 
     void createActions(KActionCollection *ac);
@@ -48,4 +48,3 @@ private:
     std::unique_ptr<RichTextComposerActionsPrivate> const d;
 };
 }
-
