@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "emoticonunicodeproxymodel.h"
 #include "emoticonunicodemodel.h"
-#include <QDebug>
 using namespace KPIMTextEdit;
 EmoticonUnicodeProxyModel::EmoticonUnicodeProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
@@ -14,9 +13,7 @@ EmoticonUnicodeProxyModel::EmoticonUnicodeProxyModel(QObject *parent)
     setFilterRole(EmoticonUnicodeModel::UnicodeEmoji);
 }
 
-EmoticonUnicodeProxyModel::~EmoticonUnicodeProxyModel()
-{
-}
+EmoticonUnicodeProxyModel::~EmoticonUnicodeProxyModel() = default;
 
 bool EmoticonUnicodeProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
 {
@@ -24,8 +21,7 @@ bool EmoticonUnicodeProxyModel::filterAcceptsRow(int source_row, const QModelInd
         return QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent);
     }
     const QModelIndex sourceIndex = sourceModel()->index(source_row, 0, source_parent);
-    const EmoticonUnicodeUtils::EmoticonStruct::EmoticonType category =
-        sourceIndex.data(EmoticonUnicodeModel::Category).value<EmoticonUnicodeUtils::EmoticonStruct::EmoticonType>();
+    const auto category = sourceIndex.data(EmoticonUnicodeModel::Category).value<EmoticonUnicodeUtils::EmoticonStruct::EmoticonType>();
     if (mCategories == category) {
         return true;
     }
