@@ -133,8 +133,9 @@ private:
     void checkSpelling(bool force);
     void moveLineUpDown(bool moveUp);
     void moveCursorBeginUpDown(bool moveUp);
+    void regenerateColorScheme();
+    void updateReadOnlyColor();
     class RichTextEditorPrivate;
     std::unique_ptr<RichTextEditorPrivate> const d;
 };
 }
-
