@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ TextToSpeech::TextToSpeech(QObject *parent)
     reloadSettings();
 }
 
-TextToSpeech::~TextToSpeech()
-{
-}
+TextToSpeech::~TextToSpeech() = default;
 
 void TextToSpeech::reloadSettings()
 {
